summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kscheduledlistitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kscheduledlistitem.h')
-rw-r--r--kmymoney2/views/kscheduledlistitem.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kmymoney2/views/kscheduledlistitem.h b/kmymoney2/views/kscheduledlistitem.h
index c5e4728..62df861 100644
--- a/kmymoney2/views/kscheduledlistitem.h
+++ b/kmymoney2/views/kscheduledlistitem.h
@@ -26,7 +26,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qpixmap.h>
+#include <tqpixmap.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -56,27 +56,27 @@ public:
*
* Other types may be added in the future.
*
* @param parent The list view to be a child of.
* @param description The (translated) description.
* @param pixmap A pixmap for the entry
* @param sortKey a sortkey, if empty, @c description will be used.
*
* @see MyMoneySchedule
*/
- KScheduledListItem(KListView *parent, const QString& description, const QPixmap& pixmap = QPixmap(), const QString& sortKey = QString());
+ KScheduledListItem(KListView *tqparent, const TQString& description, const TQPixmap& pixmap = TQPixmap(), const TQString& sortKey = TQString());
/**
- * This constructor is used to create a child of one of the children
+ * This constructor is used to create a child of one of the tqchildren
* created by the above method.
*
* This child describes a schedule and represents the data in schedule.
*
* @param parent The list view item to be a child of.
* @param schedule The schedule to be represented.
*
* @see MyMoneySchedule
*/
- KScheduledListItem(KScheduledListItem *parent, const MyMoneySchedule& schedule/*, bool even*/);
+ KScheduledListItem(KScheduledListItem *tqparent, const MyMoneySchedule& schedule/*, bool even*/);
/**
* Standard destructor.
@@ -91,16 +91,16 @@ public:
*
* @return The schedule id.
*/
- const QString& scheduleId(void) const { return m_schedule.id(); }
+ const TQString& scheduleId(void) const { return m_schedule.id(); }
- int compare(QListViewItem* i, int col, bool ascending) const;
+ int compare(TQListViewItem* i, int col, bool ascending) const;
protected:
- void paintCell(QPainter* p, const QColorGroup& cg, int column, int width, int align);
+ void paintCell(TQPainter* p, const TQColorGroup& cg, int column, int width, int align);
private:
MyMoneySchedule m_schedule;
- QString m_sortKey;
+ TQString m_sortKey;
MyMoneyMoney m_amount;
};
@@ -56,27 +56,27 @@ public:
* Other types may be added in the future.
*
- * @param parent The list view to be a child of.
+ * @param tqparent The list view to be a child of.
* @param description The (translated) description.
* @param pixmap A pixmap for the entry
@@ -56,27 +56,27 @@ public:
* This child describes a schedule and represents the data in schedule.
*
- * @param parent The list view item to be a child of.
+ * @param tqparent The list view item to be a child of.
* @param schedule The schedule to be represented.
*